#!/usr/bin/perl
#========================================================
# Examples on how to run...
#
#     perl main.pl surfrad dra 200904 200904
#     perl main.pl sgp e13 200001 200001
#     perl main.pl twp manus 199901 199901
#
# SURFRAD SITES (surfrad)     ARM SITES (sgp or twp)
# Table Mountain -> bos     Billings/BSRN        -> bil
# Desert Rock    -> dra     Extended Facility 13 -> e13
# Fort Peck      -> fpe                          -> brs
# Goodwin Creek  -> gcr
# Bondville      -> bon     Manus Island         -> manus
# Penn State     -> psu     Nauru Island         -> nauru
# Sioux Falls    -> sxf     Darwin Australia     -> darwin
#
#========================================================
use Time::DaysInMonth;

$site_type = shift;
$site      = shift; 
$start     = shift;
$end       = shift;

#
# Defines the required files depending on $site_type
#
my $path = "./Common";
if ($site_type eq "surfrad") {
    require "$path/header1.pl";
    require "$path/header2.pl";
    require "data.pl";
    $opath =".";
} else { die "Site Type is not acceptable.  Check"}

$site = substr($site,0,3); 

$start =~ /(\d\d\d\d)(\d\d)/;
$beg_year  = $1;
$beg_mon = $2;

$end   =~ /(\d\d\d\d)(\d\d)/;
$end_year  = $1;
$end_mon = $2;

# Error checking for begin and end times
if ($beg_year < 1990) {die "Begin year out of range.  Check";}
if ($end_year > 2050) {die "End year out of range.  Check";}
if ($beg_mon < 1 || $beg_mon > 12) {die "Begin month out of range.  Check";}
if ($end_mon < 1 || $end_mon > 12) {die "End month out of range.  Check";}
my $begsecs = timegm(0,0,0,1,$beg_mon-1,$beg_year);
my $endsecs = timegm(0,0,0,1,$end_mon-1,$end_year);
if ($begsecs > $endsecs) {die "BEGIN time can't be after END time!  Check";}

$year_calc  = (($end_year - $beg_year)*12);
$num_months = (($end_mon + $year_calc) - $beg_mon) + 1;  # Number of months

$cnt  = 1;
$year = $beg_year;
$mon  = $beg_mon;
@dates_to_calc = ();
while ($cnt < ($num_months + 1)) {
    if ($mon == 13) {
	$year++;
	$mon = 1;
    }
    push @dates_to_calc, (($year*100)+$mon);
    $mon++;
    $cnt++;
}
print STDOUT "\n================================================================================\n";
print STDOUT "Going to process $num_months months of data\n\n";
print STDOUT "The $num_months months to be processed are: @dates_to_calc\n\n";
print STDOUT "Processed data will be written to: $opath\n";
print STDOUT "================================================================================\n\n";

my $mcnt = 1; # Month Count
foreach $date (@dates_to_calc) {
    my $yyyy = substr($date,0,4);
    my $yy   = substr($date,2,2);
    my $mm   = substr($date,4,2);
    my $days = days_in($yyyy,$mm); # Calculating number days in current month
    my $cnt  = 1;

    my $yyyymmdd1  = sprintf "%4d%02d%02d",$yyyy,$mm,"1";
    my $yyyymmdd2  = sprintf "%4d%02d%02d",$yyyy,$mm,$days;

    print STDOUT "Processing month $mcnt of $num_months\n\n";
    print STDOUT "Begin date for this month is $yyyymmdd1\n";
    print STDOUT " End  date for this month is $yyyymmdd2\n\n";

    while ($cnt < ($days + 1)) {
	push @files_to_process, (($date*100)+$cnt);
	$cnt++;
    }

#
# Setting the site ID as necessary
#
    my $tla = $site;

    open (F, ">$opath/$tla$mm$yy.dat") || die "error";
# warn ">>>>WRITING FILE: $opath/$site$yyyy$mm.dat";

    select(F);  # Globally sets file pointer to F
    $~ = H1_FORMAT;  # This is from header1.pl.  Confusing.  Should redo.
    header($site_type, $site, $yyyy, $mm, $days, @files_to_process);
    dataformat($site_type,$site,$yyyy,$mm,@files_to_process);
    @files_to_process = ();
    select(STDOUT);
    close(F);
$mcnt++;
}

